@@ -25,18 +25,17 @@ use winapi::um::winioctl::{
 };
 use winapi::um::winnt::{FILE_SHARE_READ, FILE_SHARE_WRITE, HANDLE};
 
-pub struct KeyHandler {
+pub(crate) struct KeyHandler {
     pub unique_id: String,
-    pub win_key: Vec<u16>,
 }
 
 impl KeyHandler {
-    pub fn new(unique_id: String, win_key: Vec<u16>) -> KeyHandler {
-        KeyHandler { unique_id, win_key }
+    pub fn new(unique_id: String) -> KeyHandler {
+        KeyHandler { unique_id }
     }
 }
 
-pub fn init_processors() -> (Vec<Processor>, String, String) {
+pub(crate) fn init_processors() -> (Vec<Processor>, String, String) {
     unsafe {
         let mut sys_info: SYSTEM_INFO = zeroed();
         GetSystemInfo(&mut sys_info);
@@ -96,7 +95,7 @@ pub unsafe fn get_disks() -> Vec<Disk> {
     #[cfg(feature = "multithread")]
     use rayon::iter::ParallelIterator;
 
-    crate::utils::into_iter(0..size_of::<DWORD>() * 8)
+    crate::utils::into_iter(0..DWORD::BITS)
         .filter_map(|x| {
             if (drives >> x) & 1 == 0 {
                 return None;
@@ -214,7 +213,7 @@ pub unsafe fn get_disks() -> Vec<Disk> {
         .collect::<Vec<_>>()
 }
 
-pub fn add_english_counter(
+pub(crate) fn add_english_counter(
     s: String,
     query: &mut Query,
     keys: &mut Option<KeyHandler>,
@@ -222,7 +221,7 @@ pub fn add_english_counter(
 ) {
     let mut full = s.encode_utf16().collect::<Vec<_>>();
     full.push(0);
-    if query.add_english_counter(&counter_name, full.clone()) {
-        *keys = Some(KeyHandler::new(counter_name, full));
+    if query.add_english_counter(&counter_name, full) {
+        *keys = Some(KeyHandler::new(counter_name));
     }
 }
